==> intel-graphics-compiler_1.0.2652.orig.tar.gz: intel-graphics-compiler-igc-1.0.2652/IGC/WrapperLLVM/include/llvmWrapper/Bitcode/BitcodeWriter.h <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#ifndef IGCLLVM_BITCODE_BITCODEWRITER_H
#define IGCLLVM_BITCODE_BITCODEWRITER_H

#include <llvm/Bitcode/BitcodeWriter.h>

namespace IGCLLVM
{
#if LLVM_VERSION_MAJOR == 4
    using llvm::WriteBitcodeToFile;
#elif LLVM_VERSION_MAJOR >= 7
    inline void WriteBitcodeToFile(const llvm::Module *M, llvm::raw_ostream &Out,
        bool ShouldPreserveUseListOrder = false,
        const llvm::ModuleSummaryIndex *Index = nullptr,
        bool GenerateHash = false,
        llvm::ModuleHash *ModHash = nullptr)
    {
        llvm::WriteBitcodeToFile(*M, Out, ShouldPreserveUseListOrder, Index, GenerateHash);
    }
#endif
}

#endif

==> intel-graphics-compiler_1.0.3627.orig.tar.gz: intel-graphics-compiler-igc-1.0.3627/IGC/WrapperLLVM/include/llvmWrapper/Bitcode/BitcodeWriter.h <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#ifndef IGCLLVM_BITCODE_BITCODEWRITER_H
#define IGCLLVM_BITCODE_BITCODEWRITER_H

#include <llvm/Bitcode/BitcodeWriter.h>
#include <llvmWrapper/IR/Module.h>

namespace IGCLLVM
{
#if LLVM_VERSION_MAJOR == 4
    using llvm::WriteBitcodeToFile;
#elif LLVM_VERSION_MAJOR >= 7
    inline void WriteBitcodeToFile(const llvm::Module *M, llvm::raw_ostream &Out,
        bool ShouldPreserveUseListOrder = false,
        const llvm::ModuleSummaryIndex *Index = nullptr,
        bool GenerateHash = false,
        llvm::ModuleHash *ModHash = nullptr)
    {
        llvm::WriteBitcodeToFile(*M, Out, ShouldPreserveUseListOrder, Index, GenerateHash);
    }
#if LLVM_VERSION_MAJOR > 8
    inline void WriteBitcodeToFile(const IGCLLVM::Module *M, llvm::raw_ostream &Out,
        bool ShouldPreserveUseListOrder = false,
        const llvm::ModuleSummaryIndex *Index = nullptr,
        bool GenerateHash = false,
        llvm::ModuleHash *ModHash = nullptr)
    {
        IGCLLVM::WriteBitcodeToFile((llvm::Module*)M, Out, ShouldPreserveUseListOrder, Index, GenerateHash);
    }
#endif
#endif
}

#endif
